==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ta/validation.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines contain the default error messages used by
    | the validator class. Some of these rules have multiple versions such
    | such as the size rules. Feel free to tweak each of these messages.
    |
    */

    'accepted'             => ': பண்புக்கூறு ஏற்றுக்கொள்ளப்பட வேண்டும்.',
    'active_url'           => 'பண்புக்கூறு: செல்லுபடியாகாத URL அல்ல.',
    'after'                => 'பின்: பண்புக்கூறு: தேதி தேதி.',
    'after_or_equal'       => 'தேதி: தேதி அல்லது அதற்கு சமமாக தேதி இருக்க வேண்டும்: தேதி.',
    'alpha'                => 'பண்புக்கூறு: கடிதங்கள் மட்டுமே கொண்டிருக்கும்.',
    'alpha_dash'           => 'பண்புக்கூறு, எண்கள், கோடுகள் ஆகியவற்றைக் கொண்டிருக்கும்.',
    'alpha_num'            => ': பண்புக்கூறுகள் மற்றும் எண்களை மட்டும் கொண்டிருக்கும்.',
    'array'                => ': பண்புக்கூறாக ஒரு வரிசை இருக்க வேண்டும்.',
    'before'               => ': பண்புக்கூறு முன் தேதி இருக்க வேண்டும்: தேதி.',
    'before_or_equal'      => 'தேதி: தேதி முன் அல்லது சமமாக தேதி இருக்க வேண்டும்: தேதி.',
    'between'              => [
        'numeric' => ': பண்புக்கூறு: நிமிடம் மற்றும் அதிகபட்சம்.',
        'file'    => 'தி: பண்புக்கூறு: நிமிடம் மற்றும்: அதிகபட்ச கிலோபைட்.',
        'string'  => 'The: பண்புக்கூறு: min மற்றும்: max characters.',
        'array'   => ': பண்புக்கூறு: நிமிடம் மற்றும்: அதிகபட்சம் உருப்படிகள்',
    ],
    'boolean'              => 'கற்பனை புலம் உண்மையாகவோ தவறாகவோ இருக்க வேண்டும்.',
    'confirmed'            => 'பண்புக்கூறு உறுதிப்படுத்தல் பொருந்தவில்லை.',
    'date'                 => ': பண்புக்கூறு சரியான தேதி அல்ல.',
    'date_format'          => 'வடிவமைப்பு: வடிவம் பொருந்தவில்லை வடிவமைப்பு.',
    'different'            => 'பண்புக்கூறு: மற்றொன்று வித்தியாசமாக இருக்க வேண்டும்.',
    'digits'               => 'பண்புக்கூறு: எண் இலக்கங்கள் இருக்க வேண்டும்.',
    'digits_between'       => ': பண்புக்கூறு: நிமிடம் மற்றும்: அதிகபட்ச இலக்கங்கள்.',
    'dimensions'           => 'பண்புக்கூறு: தவறான பட பரிமாணங்களை கொண்டுள்ளது.',
    'distinct'             => ': பண்புக்கூறு துறையில் ஒரு போலி மதிப்பு உள்ளது.',
    'email'                => 'பண்புக்கூறு: செல்லுபடியாகும் மின்னஞ்சல் முகவரி இருக்க வேண்டும்.',
    'exists'               => 'தேர்ந்தெடுக்கப்பட்ட: பண்பு தவறானது.',
    'file'                 => 'பண்புக்கூறு ஒரு கோப்பாக இருக்க வேண்டும்.',
    'filled'               => 'பண்புக்கூறு துறையில் ஒரு மதிப்பு இருக்க வேண்டும்.',
    'image'                => 'பண்புக்கூறு: ஒரு படம் இருக்க வேண்டும்.',
    'in'                   => 'தேர்ந்தெடுக்கப்பட்ட: பண்பு தவறானது.',
    'in_array'             => ': பண்புக்கூறு புலம் இல்லை: மற்றவை.',
    'integer'              => 'பண்புக்கூறு: ஒரு முழு எண்ணாக இருக்க வேண்டும்.',
    'ip'                   => 'பண்புக்கூறு: செல்லுபடியாகும் IP முகவரி இருக்க வேண்டும்.',
    'ipv4'                 => 'பண்புக்கூறு: செல்லுபடியாகும் IPv4 முகவரி இருக்க வேண்டும்.',
    'ipv6'                 => 'பண்புக்கூறு: செல்லுபடியாகும் IPv6 முகவரி இருக்க வேண்டும்.',
    'json'                 => 'பண்புக்கூறு செல்லுபடியான JSON சரமாக இருக்க வேண்டும்.',
    'max'                  => [
        'numeric' => ': பண்புக்கூறு அதிகமாக இருக்கலாம்: அதிகபட்சம்.',
        'file'    => 'உருக்கு: பண்பு அதிகமாக இருக்கலாம்: அதிகபட்ச கிலோபைட்.',
        'string'  => ': பண்புக்கூறு அதிகமாக இருக்கலாம்: அதிக எழுத்துகள்.',
        'array'   => ': பண்புக்கூறு அதிகமாக இல்லை: அதிகபட்சம் பொருட்களை.',
    ],
    'mimes'                => 'வகை: வகை ஒரு கோப்பு இருக்க வேண்டும்:: மதிப்புகள்.',
    'mimetypes'            => 'வகை: வகை ஒரு கோப்பு இருக்க வேண்டும்:: மதிப்புகள்.',
    'min'                  => [
        'numeric' => ': பண்புக்கூறு குறைந்தது: நிமிடம்.',
        'file'    => ': பண்புக்கூறு குறைந்தது: நிமிட கிலோபைட்.',
        'string'  => ': பண்புக்கூறு குறைந்தது: குறைந்த எழுத்துகள்.',
        'array'   => ': பண்புக்கூறு குறைந்தபட்சம்: நிமிடம் உருப்படிகள் வேண்டும்.',
    ],
    'not_in'               => 'தேர்ந்தெடுக்கப்பட்ட: பண்பு தவறானது.',
    'numeric'              => 'பண்புக்கூறு: ஒரு எண் இருக்க வேண்டும்.',
    'present'              => ': பண்புக்கூறு களஞ்சியம் இருக்க வேண்டும்.',
    'valid_regex'          => 'That is not a valid regex. ',
    'regex'                => 'பண்புக்கூறு வடிவமைப்பு தவறானது.',
    'required'             => ': பண்புக்கூறு தேவைப்படுகிறது.',
    'required_if'          => ': பண்புக்கூறு புலம் தேவை: மற்றது: மதிப்பு.',
    'required_unless'      => ': பண்புக்கூறு தேவைப்படுகிறது: மற்றது: மதிப்புகள்.',
    'required_with'        => ': பண்புக்கூறு: போது மதிப்புகள் உள்ளது.',
    'required_with_all'    => ': பண்புக்கூறு: போது மதிப்புகள் உள்ளது.',
    'required_without'     => ': பண்புக்கூறு புலம் தேவை: மதிப்புகள் இல்லை.',
    'required_without_all' => ': மதிப்புகள் இல்லை போது பண்பு துறையில் தேவைப்படுகிறது.',
    'same'                 => 'பண்புக்கூறு: மற்றொன்று பொருந்த வேண்டும்.',
    'size'                 => [
        'numeric' => 'பண்புக்கூறு: அளவு இருக்க வேண்டும்.',
        'file'    => 'பண்புக்கூறு: அளவு கிலோபைட்டுகள்.',
        'string'  => 'பண்புக்கூறு: அளவுருக்கள் இருக்க வேண்டும்.',
        'array'   => ': பண்புக்கூறு: அளவு உருப்படிகளைக் கொண்டிருக்க வேண்டும்.',
    ],
    'string'               => 'பண்புக்கூறு ஒரு சரம் இருக்க வேண்டும்.',
    'timezone'             => 'பண்புக்கூறு: செல்லுபடியாகும் மண்டலம் இருக்க வேண்டும்.',
    'unique'               => ': பண்பு ஏற்கனவே ஏற்கப்பட்டுள்ளது.',
    'uploaded'             => ': பண்புக்கூறு பதிவேற்றத் தவறியது.',
    'url'                  => 'பண்புக்கூறு வடிவமைப்பு தவறானது.',
    "unique_undeleted"     => "The :attribute must be unique.",

    /*
    |--------------------------------------------------------------------------
    | Custom Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | Here you may specify custom validation messages for attributes using the
    | convention "attribute.rule" to name the lines. This makes it quick to
    | specify a specific custom language line for a given attribute rule.
    |
    */


    /*
    |--------------------------------------------------------------------------
    | Custom Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | Here you may specify custom validation messages for attributes using the
    | convention "attribute.rule" to name the lines. This makes it quick to
    | specify a specific custom language line for a given attribute rule.
    |
    */

    'custom' => [
        'alpha_space' => "பண்புக்கூறு துறையில் அனுமதிக்கப்படாத ஒரு பாத்திரம் உள்ளது.",
        "email_array"      => "ஒன்று அல்லது அதற்கு மேற்பட்ட மின்னஞ்சல் முகவரிகள் தவறானவை.",
        "hashed_pass"      => "உங்கள் தற்போதைய கடவுச்சொல் தவறானது",
        'dumbpwd'          => 'அந்த கடவுச்சொல் மிகவும் பொதுவானது.',
        "statuslabel_type" => "செல்லுபடியாகும் நிலை லேபிள் வகை தேர்ந்தெடுக்க வேண்டும்",
    ],

    /*
    |--------------------------------------------------------------------------
    | Custom Validation Attributes
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to swap attribute place-holders
    | with something more reader friendly such as E-Mail Address instead
    | of "email". This simply helps us make messages a little cleaner.
    |
    */

    'attributes' => [],

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ta/validation.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines contain the default error messages used by
    | the validator class. Some of these rules have multiple versions such
    | such as the size rules. Feel free to tweak each of these messages.
    |
    */

    'accepted'             => ': பண்புக்கூறு ஏற்றுக்கொள்ளப்பட வேண்டும்.',
    'active_url'           => 'பண்புக்கூறு: செல்லுபடியாகாத URL அல்ல.',
    'after'                => 'பின்: பண்புக்கூறு: தேதி தேதி.',
    'after_or_equal'       => 'தேதி: தேதி அல்லது அதற்கு சமமாக தேதி இருக்க வேண்டும்: தேதி.',
    'alpha'                => 'பண்புக்கூறு: கடிதங்கள் மட்டுமே கொண்டிருக்கும்.',
    'alpha_dash'           => 'பண்புக்கூறு, எண்கள், கோடுகள் ஆகியவற்றைக் கொண்டிருக்கும்.',
    'alpha_num'            => ': பண்புக்கூறுகள் மற்றும் எண்களை மட்டும் கொண்டிருக்கும்.',
    'array'                => ': பண்புக்கூறாக ஒரு வரிசை இருக்க வேண்டும்.',
    'before'               => ': பண்புக்கூறு முன் தேதி இருக்க வேண்டும்: தேதி.',
    'before_or_equal'      => 'தேதி: தேதி முன் அல்லது சமமாக தேதி இருக்க வேண்டும்: தேதி.',
    'between'              => [
        'numeric' => ': பண்புக்கூறு: நிமிடம் மற்றும் அதிகபட்சம்.',
        'file'    => 'தி: பண்புக்கூறு: நிமிடம் மற்றும்: அதிகபட்ச கிலோபைட்.',
        'string'  => 'The: பண்புக்கூறு: min மற்றும்: max characters.',
        'array'   => ': பண்புக்கூறு: நிமிடம் மற்றும்: அதிகபட்சம் உருப்படிகள்',
    ],
    'boolean'              => 'கற்பனை புலம் உண்மையாகவோ தவறாகவோ இருக்க வேண்டும்.',
    'confirmed'            => 'பண்புக்கூறு உறுதிப்படுத்தல் பொருந்தவில்லை.',
    'date'                 => ': பண்புக்கூறு சரியான தேதி அல்ல.',
    'date_format'          => 'வடிவமைப்பு: வடிவம் பொருந்தவில்லை வடிவமைப்பு.',
    'different'            => 'பண்புக்கூறு: மற்றொன்று வித்தியாசமாக இருக்க வேண்டும்.',
    'digits'               => 'பண்புக்கூறு: எண் இலக்கங்கள் இருக்க வேண்டும்.',
    'digits_between'       => ': பண்புக்கூறு: நிமிடம் மற்றும்: அதிகபட்ச இலக்கங்கள்.',
    'dimensions'           => 'பண்புக்கூறு: தவறான பட பரிமாணங்களை கொண்டுள்ளது.',
    'distinct'             => ': பண்புக்கூறு துறையில் ஒரு போலி மதிப்பு உள்ளது.',
    'email'                => 'பண்புக்கூறு: செல்லுபடியாகும் மின்னஞ்சல் முகவரி இருக்க வேண்டும்.',
    'exists'               => 'தேர்ந்தெடுக்கப்பட்ட: பண்பு தவறானது.',
    'file'                 => 'பண்புக்கூறு ஒரு கோப்பாக இருக்க வேண்டும்.',
    'filled'               => 'பண்புக்கூறு துறையில் ஒரு மதிப்பு இருக்க வேண்டும்.',
    'image'                => 'பண்புக்கூறு: ஒரு படம் இருக்க வேண்டும்.',
    'in'                   => 'தேர்ந்தெடுக்கப்பட்ட: பண்பு தவறானது.',
    'in_array'             => ': பண்புக்கூறு புலம் இல்லை: மற்றவை.',
    'integer'              => 'பண்புக்கூறு: ஒரு முழு எண்ணாக இருக்க வேண்டும்.',
    'ip'                   => 'பண்புக்கூறு: செல்லுபடியாகும் IP முகவரி இருக்க வேண்டும்.',
    'ipv4'                 => 'பண்புக்கூறு: செல்லுபடியாகும் IPv4 முகவரி இருக்க வேண்டும்.',
    'ipv6'                 => 'பண்புக்கூறு: செல்லுபடியாகும் IPv6 முகவரி இருக்க வேண்டும்.',
    'json'                 => 'பண்புக்கூறு செல்லுபடியான JSON சரமாக இருக்க வேண்டும்.',
    'max'                  => [
        'numeric' => ': பண்புக்கூறு அதிகமாக இருக்கலாம்: அதிகபட்சம்.',
        'file'    => 'உருக்கு: பண்பு அதிகமாக இருக்கலாம்: அதிகபட்ச கிலோபைட்.',
        'string'  => ': பண்புக்கூறு அதிகமாக இருக்கலாம்: அதிக எழுத்துகள்.',
        'array'   => ': பண்புக்கூறு அதிகமாக இல்லை: அதிகபட்சம் பொருட்களை.',
    ],
    'mimes'                => 'வகை: வகை ஒரு கோப்பு இருக்க வேண்டும்:: மதிப்புகள்.',
    'mimetypes'            => 'வகை: வகை ஒரு கோப்பு இருக்க வேண்டும்:: மதிப்புகள்.',
    'min'                  => [
        'numeric' => ': பண்புக்கூறு குறைந்தது: நிமிடம்.',
        'file'    => ': பண்புக்கூறு குறைந்தது: நிமிட கிலோபைட்.',
        'string'  => ': பண்புக்கூறு குறைந்தது: குறைந்த எழுத்துகள்.',
        'array'   => ': பண்புக்கூறு குறைந்தபட்சம்: நிமிடம் உருப்படிகள் வேண்டும்.',
    ],
    'starts_with'          => 'The :attribute must start with one of the following: :values.',
    'not_in'               => 'தேர்ந்தெடுக்கப்பட்ட: பண்பு தவறானது.',
    'numeric'              => 'பண்புக்கூறு: ஒரு எண் இருக்க வேண்டும்.',
    'present'              => ': பண்புக்கூறு களஞ்சியம் இருக்க வேண்டும்.',
    'valid_regex'          => 'That is not a valid regex. ',
    'regex'                => 'பண்புக்கூறு வடிவமைப்பு தவறானது.',
    'required'             => ': பண்புக்கூறு தேவைப்படுகிறது.',
    'required_if'          => ': பண்புக்கூறு புலம் தேவை: மற்றது: மதிப்பு.',
    'required_unless'      => ': பண்புக்கூறு தேவைப்படுகிறது: மற்றது: மதிப்புகள்.',
    'required_with'        => ': பண்புக்கூறு: போது மதிப்புகள் உள்ளது.',
    'required_with_all'    => ': பண்புக்கூறு: போது மதிப்புகள் உள்ளது.',
    'required_without'     => ': பண்புக்கூறு புலம் தேவை: மதிப்புகள் இல்லை.',
    'required_without_all' => ': மதிப்புகள் இல்லை போது பண்பு துறையில் தேவைப்படுகிறது.',
    'same'                 => 'பண்புக்கூறு: மற்றொன்று பொருந்த வேண்டும்.',
    'size'                 => [
        'numeric' => 'பண்புக்கூறு: அளவு இருக்க வேண்டும்.',
        'file'    => 'பண்புக்கூறு: அளவு கிலோபைட்டுகள்.',
        'string'  => 'பண்புக்கூறு: அளவுருக்கள் இருக்க வேண்டும்.',
        'array'   => ': பண்புக்கூறு: அளவு உருப்படிகளைக் கொண்டிருக்க வேண்டும்.',
    ],
    'string'               => 'பண்புக்கூறு ஒரு சரம் இருக்க வேண்டும்.',
    'timezone'             => 'பண்புக்கூறு: செல்லுபடியாகும் மண்டலம் இருக்க வேண்டும்.',
    'unique'               => ': பண்பு ஏற்கனவே ஏற்கப்பட்டுள்ளது.',
    'uploaded'             => ': பண்புக்கூறு பதிவேற்றத் தவறியது.',
    'url'                  => 'பண்புக்கூறு வடிவமைப்பு தவறானது.',
    'unique_undeleted'     => 'The :attribute must be unique.',
    'non_circular'         => 'The :attribute must not create a circular reference.',

    /*
    |--------------------------------------------------------------------------
    | Custom Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | Here you may specify custom validation messages for attributes using the
    | convention "attribute.rule" to name the lines. This makes it quick to
    | specify a specific custom language line for a given attribute rule.
    |
    */

    /*
    |--------------------------------------------------------------------------
    | Custom Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | Here you may specify custom validation messages for attributes using the
    | convention "attribute.rule" to name the lines. This makes it quick to
    | specify a specific custom language line for a given attribute rule.
    |
    */

    'custom' => [
        'alpha_space' => 'பண்புக்கூறு துறையில் அனுமதிக்கப்படாத ஒரு பாத்திரம் உள்ளது.',
        'email_array'      => 'ஒன்று அல்லது அதற்கு மேற்பட்ட மின்னஞ்சல் முகவரிகள் தவறானவை.',
        'hashed_pass'      => 'உங்கள் தற்போதைய கடவுச்சொல் தவறானது',
        'dumbpwd'          => 'அந்த கடவுச்சொல் மிகவும் பொதுவானது.',
        'statuslabel_type' => 'செல்லுபடியாகும் நிலை லேபிள் வகை தேர்ந்தெடுக்க வேண்டும்',
    ],

    /*
    |--------------------------------------------------------------------------
    | Custom Validation Attributes
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to swap attribute place-holders
    | with something more reader friendly such as E-Mail Address instead
    | of "email". This simply helps us make messages a little cleaner.
    |
    */

    'attributes' => [],

];
